
# Dexo

A python based command line utility for quick and easy
web development project initialisation.

## Installation:
To install dexo on windows,

```
> pip install dexo
```

and to install dexo on unix systems

```
$ pip3 install dexo
```

## Usage:
To create a new project
```
> dexo { project_name }
```
and you can give project_name as your project's name.
dexo creates the following files for you,

- index.html
- style.css
- app.js
- README.md

## Links

[github](https://github.com/kavinbharathii/webdev)
